# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['DeviceArgs', 'Device']

@pulumi.input_type
class DeviceArgs:
    def __init__(__self__, *,
                 configsync_ip: pulumi.Input[str],
                 name: pulumi.Input[str],
                 mirror_ip: Optional[pulumi.Input[str]] = None,
                 mirror_secondary_ip: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Device resource.
        :param pulumi.Input[str] configsync_ip: IP address used for config sync
        :param pulumi.Input[str] name: Address of the Device which needs to be Deviceensed
        :param pulumi.Input[str] mirror_ip: IP address used for state mirroring
        :param pulumi.Input[str] mirror_secondary_ip: Secondary IP address used for state mirroring
        """
        pulumi.set(__self__, "configsync_ip", configsync_ip)
        pulumi.set(__self__, "name", name)
        if mirror_ip is not None:
            pulumi.set(__self__, "mirror_ip", mirror_ip)
        if mirror_secondary_ip is not None:
            pulumi.set(__self__, "mirror_secondary_ip", mirror_secondary_ip)

    @property
    @pulumi.getter(name="configsyncIp")
    def configsync_ip(self) -> pulumi.Input[str]:
        """
        IP address used for config sync
        """
        return pulumi.get(self, "configsync_ip")

    @configsync_ip.setter
    def configsync_ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "configsync_ip", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Address of the Device which needs to be Deviceensed
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="mirrorIp")
    def mirror_ip(self) -> Optional[pulumi.Input[str]]:
        """
        IP address used for state mirroring
        """
        return pulumi.get(self, "mirror_ip")

    @mirror_ip.setter
    def mirror_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mirror_ip", value)

    @property
    @pulumi.getter(name="mirrorSecondaryIp")
    def mirror_secondary_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Secondary IP address used for state mirroring
        """
        return pulumi.get(self, "mirror_secondary_ip")

    @mirror_secondary_ip.setter
    def mirror_secondary_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mirror_secondary_ip", value)


@pulumi.input_type
class _DeviceState:
    def __init__(__self__, *,
                 configsync_ip: Optional[pulumi.Input[str]] = None,
                 mirror_ip: Optional[pulumi.Input[str]] = None,
                 mirror_secondary_ip: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Device resources.
        :param pulumi.Input[str] configsync_ip: IP address used for config sync
        :param pulumi.Input[str] mirror_ip: IP address used for state mirroring
        :param pulumi.Input[str] mirror_secondary_ip: Secondary IP address used for state mirroring
        :param pulumi.Input[str] name: Address of the Device which needs to be Deviceensed
        """
        if configsync_ip is not None:
            pulumi.set(__self__, "configsync_ip", configsync_ip)
        if mirror_ip is not None:
            pulumi.set(__self__, "mirror_ip", mirror_ip)
        if mirror_secondary_ip is not None:
            pulumi.set(__self__, "mirror_secondary_ip", mirror_secondary_ip)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="configsyncIp")
    def configsync_ip(self) -> Optional[pulumi.Input[str]]:
        """
        IP address used for config sync
        """
        return pulumi.get(self, "configsync_ip")

    @configsync_ip.setter
    def configsync_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "configsync_ip", value)

    @property
    @pulumi.getter(name="mirrorIp")
    def mirror_ip(self) -> Optional[pulumi.Input[str]]:
        """
        IP address used for state mirroring
        """
        return pulumi.get(self, "mirror_ip")

    @mirror_ip.setter
    def mirror_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mirror_ip", value)

    @property
    @pulumi.getter(name="mirrorSecondaryIp")
    def mirror_secondary_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Secondary IP address used for state mirroring
        """
        return pulumi.get(self, "mirror_secondary_ip")

    @mirror_secondary_ip.setter
    def mirror_secondary_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "mirror_secondary_ip", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Address of the Device which needs to be Deviceensed
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


class Device(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 configsync_ip: Optional[pulumi.Input[str]] = None,
                 mirror_ip: Optional[pulumi.Input[str]] = None,
                 mirror_secondary_ip: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `cm.Device` provides details about a specific bigip

        This resource is helpful when configuring the BIG-IP device in cluster or in HA mode.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        my_new_device = f5bigip.cm.Device("myNewDevice",
            configsync_ip="2.2.2.2",
            mirror_ip="10.10.10.10",
            mirror_secondary_ip="11.11.11.11",
            name="bigip300.f5.com")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] configsync_ip: IP address used for config sync
        :param pulumi.Input[str] mirror_ip: IP address used for state mirroring
        :param pulumi.Input[str] mirror_secondary_ip: Secondary IP address used for state mirroring
        :param pulumi.Input[str] name: Address of the Device which needs to be Deviceensed
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DeviceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `cm.Device` provides details about a specific bigip

        This resource is helpful when configuring the BIG-IP device in cluster or in HA mode.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        my_new_device = f5bigip.cm.Device("myNewDevice",
            configsync_ip="2.2.2.2",
            mirror_ip="10.10.10.10",
            mirror_secondary_ip="11.11.11.11",
            name="bigip300.f5.com")
        ```

        :param str resource_name: The name of the resource.
        :param DeviceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DeviceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 configsync_ip: Optional[pulumi.Input[str]] = None,
                 mirror_ip: Optional[pulumi.Input[str]] = None,
                 mirror_secondary_ip: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DeviceArgs.__new__(DeviceArgs)

            if configsync_ip is None and not opts.urn:
                raise TypeError("Missing required property 'configsync_ip'")
            __props__.__dict__["configsync_ip"] = configsync_ip
            __props__.__dict__["mirror_ip"] = mirror_ip
            __props__.__dict__["mirror_secondary_ip"] = mirror_secondary_ip
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
        super(Device, __self__).__init__(
            'f5bigip:cm/device:Device',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            configsync_ip: Optional[pulumi.Input[str]] = None,
            mirror_ip: Optional[pulumi.Input[str]] = None,
            mirror_secondary_ip: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None) -> 'Device':
        """
        Get an existing Device resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] configsync_ip: IP address used for config sync
        :param pulumi.Input[str] mirror_ip: IP address used for state mirroring
        :param pulumi.Input[str] mirror_secondary_ip: Secondary IP address used for state mirroring
        :param pulumi.Input[str] name: Address of the Device which needs to be Deviceensed
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DeviceState.__new__(_DeviceState)

        __props__.__dict__["configsync_ip"] = configsync_ip
        __props__.__dict__["mirror_ip"] = mirror_ip
        __props__.__dict__["mirror_secondary_ip"] = mirror_secondary_ip
        __props__.__dict__["name"] = name
        return Device(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="configsyncIp")
    def configsync_ip(self) -> pulumi.Output[str]:
        """
        IP address used for config sync
        """
        return pulumi.get(self, "configsync_ip")

    @property
    @pulumi.getter(name="mirrorIp")
    def mirror_ip(self) -> pulumi.Output[Optional[str]]:
        """
        IP address used for state mirroring
        """
        return pulumi.get(self, "mirror_ip")

    @property
    @pulumi.getter(name="mirrorSecondaryIp")
    def mirror_secondary_ip(self) -> pulumi.Output[Optional[str]]:
        """
        Secondary IP address used for state mirroring
        """
        return pulumi.get(self, "mirror_secondary_ip")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Address of the Device which needs to be Deviceensed
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataGroupResult',
    'AwaitableGetDataGroupResult',
    'get_data_group',
    'get_data_group_output',
]

@pulumi.output_type
class GetDataGroupResult:
    """
    A collection of values returned by getDataGroup.
    """
    def __init__(__self__, id=None, name=None, partition=None, records=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)
        if records and not isinstance(records, list):
            raise TypeError("Expected argument 'records' to be a list")
        pulumi.set(__self__, "records", records)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def partition(self) -> str:
        return pulumi.get(self, "partition")

    @property
    @pulumi.getter
    def records(self) -> Sequence['outputs.GetDataGroupRecordResult']:
        """
        Specifies record of type (string/ip/integer)
        """
        return pulumi.get(self, "records")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The Data Group type (string, ip, integer)"
        """
        return pulumi.get(self, "type")


class AwaitableGetDataGroupResult(GetDataGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataGroupResult(
            id=self.id,
            name=self.name,
            partition=self.partition,
            records=self.records,
            type=self.type)


def get_data_group(name: Optional[str] = None,
                   partition: Optional[str] = None,
                   records: Optional[Sequence[pulumi.InputType['GetDataGroupRecordArgs']]] = None,
                   type: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataGroupResult:
    """
    Use this data source (`ltm.DataGroup`) to get the data group details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    d_g__tc3 = f5bigip.ltm.get_data_group(name="test-dg",
        partition="Common")
    ```


    :param str name: Name of the datagroup
    :param str partition: partition of the datagroup
    :param Sequence[pulumi.InputType['GetDataGroupRecordArgs']] records: Specifies record of type (string/ip/integer)
    :param str type: The Data Group type (string, ip, integer)"
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    __args__['records'] = records
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ltm/getDataGroup:getDataGroup', __args__, opts=opts, typ=GetDataGroupResult).value

    return AwaitableGetDataGroupResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        partition=pulumi.get(__ret__, 'partition'),
        records=pulumi.get(__ret__, 'records'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_data_group)
def get_data_group_output(name: Optional[pulumi.Input[str]] = None,
                          partition: Optional[pulumi.Input[str]] = None,
                          records: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDataGroupRecordArgs']]]]] = None,
                          type: Optional[pulumi.Input[Optional[str]]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDataGroupResult]:
    """
    Use this data source (`ltm.DataGroup`) to get the data group details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    d_g__tc3 = f5bigip.ltm.get_data_group(name="test-dg",
        partition="Common")
    ```


    :param str name: Name of the datagroup
    :param str partition: partition of the datagroup
    :param Sequence[pulumi.InputType['GetDataGroupRecordArgs']] records: Specifies record of type (string/ip/integer)
    :param str type: The Data Group type (string, ip, integer)"
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetWafEntityParameterUrlArgs',
    'GetWafEntityUrlMethodOverrideArgs',
]

@pulumi.input_type
class GetWafEntityParameterUrlArgs:
    def __init__(__self__, *,
                 method: str,
                 name: str,
                 protocol: str,
                 type: str):
        pulumi.set(__self__, "method", method)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def method(self) -> str:
        return pulumi.get(self, "method")

    @method.setter
    def method(self, value: str):
        pulumi.set(self, "method", value)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def protocol(self) -> str:
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: str):
        pulumi.set(self, "type", value)


@pulumi.input_type
class GetWafEntityUrlMethodOverrideArgs:
    def __init__(__self__, *,
                 allow: bool,
                 method: str):
        """
        :param bool allow: Specifies that the system allows or disallows a method for this URL
        :param str method: Specifies an HTTP method.
        """
        pulumi.set(__self__, "allow", allow)
        pulumi.set(__self__, "method", method)

    @property
    @pulumi.getter
    def allow(self) -> bool:
        """
        Specifies that the system allows or disallows a method for this URL
        """
        return pulumi.get(self, "allow")

    @allow.setter
    def allow(self, value: bool):
        pulumi.set(self, "allow", value)

    @property
    @pulumi.getter
    def method(self) -> str:
        """
        Specifies an HTTP method.
        """
        return pulumi.get(self, "method")

    @method.setter
    def method(self, value: str):
        pulumi.set(self, "method", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ProfileHttp2Args', 'ProfileHttp2']

@pulumi.input_type
class ProfileHttp2Args:
    def __init__(__self__, *,
                 name: pulumi.Input[str],
                 activation_modes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 concurrent_streams_per_connection: Optional[pulumi.Input[int]] = None,
                 connection_idle_timeout: Optional[pulumi.Input[int]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 enforce_tls_requirements: Optional[pulumi.Input[str]] = None,
                 frame_size: Optional[pulumi.Input[int]] = None,
                 header_table_size: Optional[pulumi.Input[int]] = None,
                 include_content_length: Optional[pulumi.Input[str]] = None,
                 insert_header: Optional[pulumi.Input[str]] = None,
                 insert_header_name: Optional[pulumi.Input[str]] = None,
                 receive_window: Optional[pulumi.Input[int]] = None,
                 write_size: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a ProfileHttp2 resource.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] activation_modes: This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        :param pulumi.Input[int] concurrent_streams_per_connection: Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        :param pulumi.Input[int] connection_idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] enforce_tls_requirements: Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        :param pulumi.Input[int] frame_size: The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        :param pulumi.Input[int] header_table_size: The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        :param pulumi.Input[str] include_content_length: Enable to include content-length in HTTP/2 headers,Default : disabled
        :param pulumi.Input[str] insert_header: This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        :param pulumi.Input[str] insert_header_name: This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        :param pulumi.Input[int] receive_window: The flow-control size for upload streams, in KB. `Default: 32`.
        :param pulumi.Input[int] write_size: The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        pulumi.set(__self__, "name", name)
        if activation_modes is not None:
            pulumi.set(__self__, "activation_modes", activation_modes)
        if concurrent_streams_per_connection is not None:
            pulumi.set(__self__, "concurrent_streams_per_connection", concurrent_streams_per_connection)
        if connection_idle_timeout is not None:
            pulumi.set(__self__, "connection_idle_timeout", connection_idle_timeout)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if enforce_tls_requirements is not None:
            pulumi.set(__self__, "enforce_tls_requirements", enforce_tls_requirements)
        if frame_size is not None:
            pulumi.set(__self__, "frame_size", frame_size)
        if header_table_size is not None:
            pulumi.set(__self__, "header_table_size", header_table_size)
        if include_content_length is not None:
            pulumi.set(__self__, "include_content_length", include_content_length)
        if insert_header is not None:
            pulumi.set(__self__, "insert_header", insert_header)
        if insert_header_name is not None:
            pulumi.set(__self__, "insert_header_name", insert_header_name)
        if receive_window is not None:
            pulumi.set(__self__, "receive_window", receive_window)
        if write_size is not None:
            pulumi.set(__self__, "write_size", write_size)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="activationModes")
    def activation_modes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        """
        return pulumi.get(self, "activation_modes")

    @activation_modes.setter
    def activation_modes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "activation_modes", value)

    @property
    @pulumi.getter(name="concurrentStreamsPerConnection")
    def concurrent_streams_per_connection(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        """
        return pulumi.get(self, "concurrent_streams_per_connection")

    @concurrent_streams_per_connection.setter
    def concurrent_streams_per_connection(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "concurrent_streams_per_connection", value)

    @property
    @pulumi.getter(name="connectionIdleTimeout")
    def connection_idle_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        """
        return pulumi.get(self, "connection_idle_timeout")

    @connection_idle_timeout.setter
    def connection_idle_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "connection_idle_timeout", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="enforceTlsRequirements")
    def enforce_tls_requirements(self) -> Optional[pulumi.Input[str]]:
        """
        Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        """
        return pulumi.get(self, "enforce_tls_requirements")

    @enforce_tls_requirements.setter
    def enforce_tls_requirements(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enforce_tls_requirements", value)

    @property
    @pulumi.getter(name="frameSize")
    def frame_size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        """
        return pulumi.get(self, "frame_size")

    @frame_size.setter
    def frame_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "frame_size", value)

    @property
    @pulumi.getter(name="headerTableSize")
    def header_table_size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        """
        return pulumi.get(self, "header_table_size")

    @header_table_size.setter
    def header_table_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "header_table_size", value)

    @property
    @pulumi.getter(name="includeContentLength")
    def include_content_length(self) -> Optional[pulumi.Input[str]]:
        """
        Enable to include content-length in HTTP/2 headers,Default : disabled
        """
        return pulumi.get(self, "include_content_length")

    @include_content_length.setter
    def include_content_length(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_content_length", value)

    @property
    @pulumi.getter(name="insertHeader")
    def insert_header(self) -> Optional[pulumi.Input[str]]:
        """
        This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        """
        return pulumi.get(self, "insert_header")

    @insert_header.setter
    def insert_header(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "insert_header", value)

    @property
    @pulumi.getter(name="insertHeaderName")
    def insert_header_name(self) -> Optional[pulumi.Input[str]]:
        """
        This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        """
        return pulumi.get(self, "insert_header_name")

    @insert_header_name.setter
    def insert_header_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "insert_header_name", value)

    @property
    @pulumi.getter(name="receiveWindow")
    def receive_window(self) -> Optional[pulumi.Input[int]]:
        """
        The flow-control size for upload streams, in KB. `Default: 32`.
        """
        return pulumi.get(self, "receive_window")

    @receive_window.setter
    def receive_window(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "receive_window", value)

    @property
    @pulumi.getter(name="writeSize")
    def write_size(self) -> Optional[pulumi.Input[int]]:
        """
        The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        return pulumi.get(self, "write_size")

    @write_size.setter
    def write_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "write_size", value)


@pulumi.input_type
class _ProfileHttp2State:
    def __init__(__self__, *,
                 activation_modes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 concurrent_streams_per_connection: Optional[pulumi.Input[int]] = None,
                 connection_idle_timeout: Optional[pulumi.Input[int]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 enforce_tls_requirements: Optional[pulumi.Input[str]] = None,
                 frame_size: Optional[pulumi.Input[int]] = None,
                 header_table_size: Optional[pulumi.Input[int]] = None,
                 include_content_length: Optional[pulumi.Input[str]] = None,
                 insert_header: Optional[pulumi.Input[str]] = None,
                 insert_header_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 receive_window: Optional[pulumi.Input[int]] = None,
                 write_size: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering ProfileHttp2 resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] activation_modes: This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        :param pulumi.Input[int] concurrent_streams_per_connection: Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        :param pulumi.Input[int] connection_idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] enforce_tls_requirements: Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        :param pulumi.Input[int] frame_size: The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        :param pulumi.Input[int] header_table_size: The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        :param pulumi.Input[str] include_content_length: Enable to include content-length in HTTP/2 headers,Default : disabled
        :param pulumi.Input[str] insert_header: This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        :param pulumi.Input[str] insert_header_name: This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        :param pulumi.Input[int] receive_window: The flow-control size for upload streams, in KB. `Default: 32`.
        :param pulumi.Input[int] write_size: The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        if activation_modes is not None:
            pulumi.set(__self__, "activation_modes", activation_modes)
        if concurrent_streams_per_connection is not None:
            pulumi.set(__self__, "concurrent_streams_per_connection", concurrent_streams_per_connection)
        if connection_idle_timeout is not None:
            pulumi.set(__self__, "connection_idle_timeout", connection_idle_timeout)
        if defaults_from is not None:
            pulumi.set(__self__, "defaults_from", defaults_from)
        if enforce_tls_requirements is not None:
            pulumi.set(__self__, "enforce_tls_requirements", enforce_tls_requirements)
        if frame_size is not None:
            pulumi.set(__self__, "frame_size", frame_size)
        if header_table_size is not None:
            pulumi.set(__self__, "header_table_size", header_table_size)
        if include_content_length is not None:
            pulumi.set(__self__, "include_content_length", include_content_length)
        if insert_header is not None:
            pulumi.set(__self__, "insert_header", insert_header)
        if insert_header_name is not None:
            pulumi.set(__self__, "insert_header_name", insert_header_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if receive_window is not None:
            pulumi.set(__self__, "receive_window", receive_window)
        if write_size is not None:
            pulumi.set(__self__, "write_size", write_size)

    @property
    @pulumi.getter(name="activationModes")
    def activation_modes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        """
        return pulumi.get(self, "activation_modes")

    @activation_modes.setter
    def activation_modes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "activation_modes", value)

    @property
    @pulumi.getter(name="concurrentStreamsPerConnection")
    def concurrent_streams_per_connection(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        """
        return pulumi.get(self, "concurrent_streams_per_connection")

    @concurrent_streams_per_connection.setter
    def concurrent_streams_per_connection(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "concurrent_streams_per_connection", value)

    @property
    @pulumi.getter(name="connectionIdleTimeout")
    def connection_idle_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        """
        return pulumi.get(self, "connection_idle_timeout")

    @connection_idle_timeout.setter
    def connection_idle_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "connection_idle_timeout", value)

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @defaults_from.setter
    def defaults_from(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defaults_from", value)

    @property
    @pulumi.getter(name="enforceTlsRequirements")
    def enforce_tls_requirements(self) -> Optional[pulumi.Input[str]]:
        """
        Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        """
        return pulumi.get(self, "enforce_tls_requirements")

    @enforce_tls_requirements.setter
    def enforce_tls_requirements(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enforce_tls_requirements", value)

    @property
    @pulumi.getter(name="frameSize")
    def frame_size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        """
        return pulumi.get(self, "frame_size")

    @frame_size.setter
    def frame_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "frame_size", value)

    @property
    @pulumi.getter(name="headerTableSize")
    def header_table_size(self) -> Optional[pulumi.Input[int]]:
        """
        The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        """
        return pulumi.get(self, "header_table_size")

    @header_table_size.setter
    def header_table_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "header_table_size", value)

    @property
    @pulumi.getter(name="includeContentLength")
    def include_content_length(self) -> Optional[pulumi.Input[str]]:
        """
        Enable to include content-length in HTTP/2 headers,Default : disabled
        """
        return pulumi.get(self, "include_content_length")

    @include_content_length.setter
    def include_content_length(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "include_content_length", value)

    @property
    @pulumi.getter(name="insertHeader")
    def insert_header(self) -> Optional[pulumi.Input[str]]:
        """
        This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        """
        return pulumi.get(self, "insert_header")

    @insert_header.setter
    def insert_header(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "insert_header", value)

    @property
    @pulumi.getter(name="insertHeaderName")
    def insert_header_name(self) -> Optional[pulumi.Input[str]]:
        """
        This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        """
        return pulumi.get(self, "insert_header_name")

    @insert_header_name.setter
    def insert_header_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "insert_header_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="receiveWindow")
    def receive_window(self) -> Optional[pulumi.Input[int]]:
        """
        The flow-control size for upload streams, in KB. `Default: 32`.
        """
        return pulumi.get(self, "receive_window")

    @receive_window.setter
    def receive_window(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "receive_window", value)

    @property
    @pulumi.getter(name="writeSize")
    def write_size(self) -> Optional[pulumi.Input[int]]:
        """
        The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        return pulumi.get(self, "write_size")

    @write_size.setter
    def write_size(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "write_size", value)


class ProfileHttp2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 activation_modes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 concurrent_streams_per_connection: Optional[pulumi.Input[int]] = None,
                 connection_idle_timeout: Optional[pulumi.Input[int]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 enforce_tls_requirements: Optional[pulumi.Input[str]] = None,
                 frame_size: Optional[pulumi.Input[int]] = None,
                 header_table_size: Optional[pulumi.Input[int]] = None,
                 include_content_length: Optional[pulumi.Input[str]] = None,
                 insert_header: Optional[pulumi.Input[str]] = None,
                 insert_header_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 receive_window: Optional[pulumi.Input[int]] = None,
                 write_size: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        `ltm.ProfileHttp2` Configures a custom profile_http2 for use by health checks.

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        nyhttp2 = f5bigip.ltm.ProfileHttp2("nyhttp2",
            name="/Common/test-profile-http2",
            frame_size=2021,
            receive_window=31,
            write_size=16380,
            header_table_size=4092,
            include_content_length="enabled",
            enforce_tls_requirements="enabled",
            insert_header="disabled",
            concurrent_streams_per_connection=30,
            connection_idle_timeout=100,
            activation_modes=["always"])
        #Child Profile which inherits parent http2 profile
        nyhttp2_child = f5bigip.ltm.ProfileHttp2("nyhttp2-child",
            name="/Common/test-profile-http2-child",
            defaults_from=nyhttp2.name)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] activation_modes: This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        :param pulumi.Input[int] concurrent_streams_per_connection: Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        :param pulumi.Input[int] connection_idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] enforce_tls_requirements: Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        :param pulumi.Input[int] frame_size: The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        :param pulumi.Input[int] header_table_size: The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        :param pulumi.Input[str] include_content_length: Enable to include content-length in HTTP/2 headers,Default : disabled
        :param pulumi.Input[str] insert_header: This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        :param pulumi.Input[str] insert_header_name: This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        :param pulumi.Input[int] receive_window: The flow-control size for upload streams, in KB. `Default: 32`.
        :param pulumi.Input[int] write_size: The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProfileHttp2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `ltm.ProfileHttp2` Configures a custom profile_http2 for use by health checks.

        For resources should be named with their "full path". The full path is the combination of the partition + name of the resource. For example /Common/my-pool.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        nyhttp2 = f5bigip.ltm.ProfileHttp2("nyhttp2",
            name="/Common/test-profile-http2",
            frame_size=2021,
            receive_window=31,
            write_size=16380,
            header_table_size=4092,
            include_content_length="enabled",
            enforce_tls_requirements="enabled",
            insert_header="disabled",
            concurrent_streams_per_connection=30,
            connection_idle_timeout=100,
            activation_modes=["always"])
        #Child Profile which inherits parent http2 profile
        nyhttp2_child = f5bigip.ltm.ProfileHttp2("nyhttp2-child",
            name="/Common/test-profile-http2-child",
            defaults_from=nyhttp2.name)
        ```

        :param str resource_name: The name of the resource.
        :param ProfileHttp2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProfileHttp2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 activation_modes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 concurrent_streams_per_connection: Optional[pulumi.Input[int]] = None,
                 connection_idle_timeout: Optional[pulumi.Input[int]] = None,
                 defaults_from: Optional[pulumi.Input[str]] = None,
                 enforce_tls_requirements: Optional[pulumi.Input[str]] = None,
                 frame_size: Optional[pulumi.Input[int]] = None,
                 header_table_size: Optional[pulumi.Input[int]] = None,
                 include_content_length: Optional[pulumi.Input[str]] = None,
                 insert_header: Optional[pulumi.Input[str]] = None,
                 insert_header_name: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 receive_window: Optional[pulumi.Input[int]] = None,
                 write_size: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProfileHttp2Args.__new__(ProfileHttp2Args)

            __props__.__dict__["activation_modes"] = activation_modes
            __props__.__dict__["concurrent_streams_per_connection"] = concurrent_streams_per_connection
            __props__.__dict__["connection_idle_timeout"] = connection_idle_timeout
            __props__.__dict__["defaults_from"] = defaults_from
            __props__.__dict__["enforce_tls_requirements"] = enforce_tls_requirements
            __props__.__dict__["frame_size"] = frame_size
            __props__.__dict__["header_table_size"] = header_table_size
            __props__.__dict__["include_content_length"] = include_content_length
            __props__.__dict__["insert_header"] = insert_header
            __props__.__dict__["insert_header_name"] = insert_header_name
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["receive_window"] = receive_window
            __props__.__dict__["write_size"] = write_size
        super(ProfileHttp2, __self__).__init__(
            'f5bigip:ltm/profileHttp2:ProfileHttp2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            activation_modes: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            concurrent_streams_per_connection: Optional[pulumi.Input[int]] = None,
            connection_idle_timeout: Optional[pulumi.Input[int]] = None,
            defaults_from: Optional[pulumi.Input[str]] = None,
            enforce_tls_requirements: Optional[pulumi.Input[str]] = None,
            frame_size: Optional[pulumi.Input[int]] = None,
            header_table_size: Optional[pulumi.Input[int]] = None,
            include_content_length: Optional[pulumi.Input[str]] = None,
            insert_header: Optional[pulumi.Input[str]] = None,
            insert_header_name: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            receive_window: Optional[pulumi.Input[int]] = None,
            write_size: Optional[pulumi.Input[int]] = None) -> 'ProfileHttp2':
        """
        Get an existing ProfileHttp2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] activation_modes: This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        :param pulumi.Input[int] concurrent_streams_per_connection: Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        :param pulumi.Input[int] connection_idle_timeout: Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        :param pulumi.Input[str] defaults_from: Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        :param pulumi.Input[str] enforce_tls_requirements: Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        :param pulumi.Input[int] frame_size: The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        :param pulumi.Input[int] header_table_size: The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        :param pulumi.Input[str] include_content_length: Enable to include content-length in HTTP/2 headers,Default : disabled
        :param pulumi.Input[str] insert_header: This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        :param pulumi.Input[str] insert_header_name: This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        :param pulumi.Input[str] name: Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        :param pulumi.Input[int] receive_window: The flow-control size for upload streams, in KB. `Default: 32`.
        :param pulumi.Input[int] write_size: The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProfileHttp2State.__new__(_ProfileHttp2State)

        __props__.__dict__["activation_modes"] = activation_modes
        __props__.__dict__["concurrent_streams_per_connection"] = concurrent_streams_per_connection
        __props__.__dict__["connection_idle_timeout"] = connection_idle_timeout
        __props__.__dict__["defaults_from"] = defaults_from
        __props__.__dict__["enforce_tls_requirements"] = enforce_tls_requirements
        __props__.__dict__["frame_size"] = frame_size
        __props__.__dict__["header_table_size"] = header_table_size
        __props__.__dict__["include_content_length"] = include_content_length
        __props__.__dict__["insert_header"] = insert_header
        __props__.__dict__["insert_header_name"] = insert_header_name
        __props__.__dict__["name"] = name
        __props__.__dict__["receive_window"] = receive_window
        __props__.__dict__["write_size"] = write_size
        return ProfileHttp2(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="activationModes")
    def activation_modes(self) -> pulumi.Output[Sequence[str]]:
        """
        This setting specifies the condition that will cause the BIG-IP system to handle an incoming connection as an HTTP/2 connection, Allowed values : `[“alpn”]` (or) `[“always”]`.
        """
        return pulumi.get(self, "activation_modes")

    @property
    @pulumi.getter(name="concurrentStreamsPerConnection")
    def concurrent_streams_per_connection(self) -> pulumi.Output[int]:
        """
        Specifies how many concurrent requests are allowed to be outstanding on a single HTTP/2 connection.
        """
        return pulumi.get(self, "concurrent_streams_per_connection")

    @property
    @pulumi.getter(name="connectionIdleTimeout")
    def connection_idle_timeout(self) -> pulumi.Output[int]:
        """
        Specifies the number of seconds that a connection is idle before the connection is eligible for deletion.
        """
        return pulumi.get(self, "connection_idle_timeout")

    @property
    @pulumi.getter(name="defaultsFrom")
    def defaults_from(self) -> pulumi.Output[str]:
        """
        Specifies the profile that you want to use as the parent profile. Your new profile inherits all settings and values from the parent profile specified.
        """
        return pulumi.get(self, "defaults_from")

    @property
    @pulumi.getter(name="enforceTlsRequirements")
    def enforce_tls_requirements(self) -> pulumi.Output[str]:
        """
        Enable or disable enforcement of TLS requirements,Allowed Values : `"enabled"/"disabled"` [Default:`"enabled"`].
        """
        return pulumi.get(self, "enforce_tls_requirements")

    @property
    @pulumi.getter(name="frameSize")
    def frame_size(self) -> pulumi.Output[int]:
        """
        The size of the data frames, in bytes, that the HTTP/2 protocol sends to the client. `Default: 2048`.
        """
        return pulumi.get(self, "frame_size")

    @property
    @pulumi.getter(name="headerTableSize")
    def header_table_size(self) -> pulumi.Output[int]:
        """
        The size of the header table, in KB, for the HTTP headers that the HTTP/2 protocol compresses to save bandwidth.
        """
        return pulumi.get(self, "header_table_size")

    @property
    @pulumi.getter(name="includeContentLength")
    def include_content_length(self) -> pulumi.Output[str]:
        """
        Enable to include content-length in HTTP/2 headers,Default : disabled
        """
        return pulumi.get(self, "include_content_length")

    @property
    @pulumi.getter(name="insertHeader")
    def insert_header(self) -> pulumi.Output[str]:
        """
        This setting specifies whether the BIG-IP system should add an HTTP header to the HTTP request to show that the request was received over HTTP/2, Allowed Values : `"enabled"/"disabled"` [ Default: `"disabled"`].
        """
        return pulumi.get(self, "insert_header")

    @property
    @pulumi.getter(name="insertHeaderName")
    def insert_header_name(self) -> pulumi.Output[str]:
        """
        This setting specifies the name of the header that the BIG-IP system will add to the HTTP request when the Insert Header is enabled.
        """
        return pulumi.get(self, "insert_header_name")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of Profile should be full path.The full path is the combination of the `partition + profile name`,For example `/Common/test-http2-profile`.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="receiveWindow")
    def receive_window(self) -> pulumi.Output[int]:
        """
        The flow-control size for upload streams, in KB. `Default: 32`.
        """
        return pulumi.get(self, "receive_window")

    @property
    @pulumi.getter(name="writeSize")
    def write_size(self) -> pulumi.Output[int]:
        """
        The total size of combined data frames, in bytes, that the HTTP/2 protocol sends in a single write function. `Default: 16384`".
        """
        return pulumi.get(self, "write_size")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['As3Args', 'As3']

@pulumi.input_type
class As3Args:
    def __init__(__self__, *,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a As3 resource.
        :param pulumi.Input[str] application_list: Name of Application
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```python
               import pulumi
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: Name of Tenant
        :param pulumi.Input[str] tenant_name: Name of Tenant
        """
        if application_list is not None:
            pulumi.set(__self__, "application_list", application_list)
        if as3_json is not None:
            pulumi.set(__self__, "as3_json", as3_json)
        if ignore_metadata is not None:
            pulumi.set(__self__, "ignore_metadata", ignore_metadata)
        if task_id is not None:
            pulumi.set(__self__, "task_id", task_id)
        if tenant_filter is not None:
            pulumi.set(__self__, "tenant_filter", tenant_filter)
        if tenant_list is not None:
            pulumi.set(__self__, "tenant_list", tenant_list)
        if tenant_name is not None:
            warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
            pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")
        if tenant_name is not None:
            pulumi.set(__self__, "tenant_name", tenant_name)

    @property
    @pulumi.getter(name="applicationList")
    def application_list(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Application
        """
        return pulumi.get(self, "application_list")

    @application_list.setter
    def application_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_list", value)

    @property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> Optional[pulumi.Input[str]]:
        """
        Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "as3_json")

    @as3_json.setter
    def as3_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "as3_json", value)

    @property
    @pulumi.getter(name="ignoreMetadata")
    def ignore_metadata(self) -> Optional[pulumi.Input[bool]]:
        """
        Set True if you want to ignore metadata changes during update. By default it is set to false

        * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant

        ```python
        import pulumi
        ```
        * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "ignore_metadata")

    @ignore_metadata.setter
    def ignore_metadata(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ignore_metadata", value)

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of AS3 post declaration async task
        """
        return pulumi.get(self, "task_id")

    @task_id.setter
    def task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "task_id", value)

    @property
    @pulumi.getter(name="tenantFilter")
    def tenant_filter(self) -> Optional[pulumi.Input[str]]:
        """
        If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        """
        return pulumi.get(self, "tenant_filter")

    @tenant_filter.setter
    def tenant_filter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_filter", value)

    @property
    @pulumi.getter(name="tenantList")
    def tenant_list(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Tenant
        """
        return pulumi.get(self, "tenant_list")

    @tenant_list.setter
    def tenant_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_list", value)

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Tenant
        """
        warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
        pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")

        return pulumi.get(self, "tenant_name")

    @tenant_name.setter
    def tenant_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_name", value)


@pulumi.input_type
class _As3State:
    def __init__(__self__, *,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering As3 resources.
        :param pulumi.Input[str] application_list: Name of Application
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```python
               import pulumi
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: Name of Tenant
        :param pulumi.Input[str] tenant_name: Name of Tenant
        """
        if application_list is not None:
            pulumi.set(__self__, "application_list", application_list)
        if as3_json is not None:
            pulumi.set(__self__, "as3_json", as3_json)
        if ignore_metadata is not None:
            pulumi.set(__self__, "ignore_metadata", ignore_metadata)
        if task_id is not None:
            pulumi.set(__self__, "task_id", task_id)
        if tenant_filter is not None:
            pulumi.set(__self__, "tenant_filter", tenant_filter)
        if tenant_list is not None:
            pulumi.set(__self__, "tenant_list", tenant_list)
        if tenant_name is not None:
            warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
            pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")
        if tenant_name is not None:
            pulumi.set(__self__, "tenant_name", tenant_name)

    @property
    @pulumi.getter(name="applicationList")
    def application_list(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Application
        """
        return pulumi.get(self, "application_list")

    @application_list.setter
    def application_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "application_list", value)

    @property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> Optional[pulumi.Input[str]]:
        """
        Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "as3_json")

    @as3_json.setter
    def as3_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "as3_json", value)

    @property
    @pulumi.getter(name="ignoreMetadata")
    def ignore_metadata(self) -> Optional[pulumi.Input[bool]]:
        """
        Set True if you want to ignore metadata changes during update. By default it is set to false

        * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant

        ```python
        import pulumi
        ```
        * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "ignore_metadata")

    @ignore_metadata.setter
    def ignore_metadata(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ignore_metadata", value)

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of AS3 post declaration async task
        """
        return pulumi.get(self, "task_id")

    @task_id.setter
    def task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "task_id", value)

    @property
    @pulumi.getter(name="tenantFilter")
    def tenant_filter(self) -> Optional[pulumi.Input[str]]:
        """
        If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        """
        return pulumi.get(self, "tenant_filter")

    @tenant_filter.setter
    def tenant_filter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_filter", value)

    @property
    @pulumi.getter(name="tenantList")
    def tenant_list(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Tenant
        """
        return pulumi.get(self, "tenant_list")

    @tenant_list.setter
    def tenant_list(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_list", value)

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of Tenant
        """
        warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
        pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")

        return pulumi.get(self, "tenant_name")

    @tenant_name.setter
    def tenant_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_name", value)


class As3(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        `As3` provides details about bigip as3 resource

        This resource is helpful to configure as3 declarative JSON on BIG-IP.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        # Example Usage for json file
        as3_example1_as3 = f5bigip.As3("as3-example1As3", as3_json=(lambda path: open(path).read())("example1.json"))
        # Example Usage for json file with tenant filter
        as3_example1_index_as3_as3 = f5bigip.As3("as3-example1Index/as3As3",
            as3_json=(lambda path: open(path).read())("example2.json"),
            tenant_filter="Sample_03")
        ```

        ## Import

        As3 resources can be imported using the partition name, e.g., ( use comma separated partition names if there are multiple partitions in as3 deployments )

        ```sh
         $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01
        ```

        ```sh
         $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01,Sample_non_http_01
        ```

        #### Import examples ( single and multiple partitions )

        ```sh
         $ pulumi import f5bigip:index/as3:As3 test Sample_http_01
        ```

         bigip_as3.testImporting from ID "Sample_http_01"... bigip_as3.testImport prepared!

         Prepared bigip_as3 for import bigip_as3.testRefreshing state... [id=Sample_http_01] Import successful! The resources that were imported are shown above. These resources are now in your Terraform state and will henceforth be managed by Terraform. $ terraform show bigip_as3.testresource "bigip_as3" "test" {

         as3_json

        = jsonencode(

         {

         action

        = "deploy"

         class

         = "AS3"

         declaration = {

         Sample_http_01 = {

         A1

        = {

         class

        = "Application"

         jsessionid = {

         class

         = "Persist"

         cookieMethod

        = "hash"

         cookieName

        = "JSESSIONID"

         persistenceMethod = "cookie"

         }

         service

        = {

         class

        = "Service_HTTP"

         persistenceMethods = [

         {

         use = "jsessionid"

         },

         ]

         pool

         = "web_pool"

         virtualAddresses

         = [

         "10.0.2.10",

         ]

         }

         web_pool

         = {

         class

        = "Pool"

         members

        = [

         {

         serverAddresses = [

         "192.0.2.10",

         "192.0.2.11",

         ]

         servicePort

         = 80

         },

         ]

         monitors = [

         "http",

         ]

         }

         }

         class = "Tenant"

         }

         class

        = "ADC"

         id

         = "UDP_DNS_Sample"

         label

        = "UDP_DNS_Sample"

         remark

         = "Sample of a UDP DNS Load Balancer Service"

         schemaVersion

        = "3.0.0"

         }

         persist

         = true

         }

         )

         id

        = "Sample_http_01"

         tenant_filter = "Sample_http_01"

         tenant_list

         = "Sample_http_01" }

        ```sh
         $ pulumi import f5bigip:index/as3:As3 test Sample_http_01,Sample_non_http_01
        ```

         bigip_as3.testImporting from ID "Sample_http_01,Sample_non_http_01"... bigip_as3.testImport prepared!

         Prepared bigip_as3 for import bigip_as3.testRefreshing state... [id=Sample_http_01,Sample_non_http_01] Import successful! The resources that were imported are shown above. These resources are now in your Terraform state and will henceforth be managed by Terraform. $ terraform show bigip_as3.testresource "bigip_as3" "test" {

         as3_json

        = jsonencode(

         {

         action

        = "deploy"

         class

         = "AS3"

         declaration = {

         Sample_http_01

         = {

         A1

        = {

         class

        = "Application"

         jsessionid = {

         class

         = "Persist"

         cookieMethod

        = "hash"

         cookieName

        = "JSESSIONID"

         persistenceMethod = "cookie"

         }

         service

        = {

         class

        = "Service_HTTP"

         persistenceMethods = [

         {

         use = "jsessionid"

         },

         ]

         pool

         = "web_pool"

         virtualAddresses

         = [

         "10.0.2.10",

         ]

         }

         web_pool

         = {

         class

        = "Pool"

         members

        = [

         {

         serverAddresses = [

         "192.0.2.10",

         "192.0.2.11",

         ]

         servicePort

         = 80

         },

         ]

         monitors = [

         "http",

         ]

         }

         }

         class = "Tenant"

         }

         Sample_non_http_01 = {

         DNS_Service = {

         Pool1

         = {

         class

        = "Pool"

         members

        = [

         {

         serverAddresses = [

         "10.1.10.100",

         ]

         servicePort

         = 53

         },

         {

         serverAddresses = [

         "10.1.10.101",

         ]

         servicePort

         = 53

         },

         ]

         monitors = [

         "icmp",

         ]

         }

         class

         = "Application"

         service = {

         class

        = "Service_UDP"

         pool

         = "Pool1"

         virtualAddresses = [

         "10.1.20.121",

         ]

         virtualPort

        = 53

         }

         }

         class

         = "Tenant"

         }

         class

        = "ADC"

         id

         = "UDP_DNS_Sample"

         label

        = "UDP_DNS_Sample"

         remark

         = "Sample of a UDP DNS Load Balancer Service"

         schemaVersion

        = "3.0.0"

         }

         persist

         = true

         }

         )

         id

        = "Sample_http_01,Sample_non_http_01"

         tenant_filter = "Sample_http_01,Sample_non_http_01"

         tenant_list

         = "Sample_http_01,Sample_non_http_01" } * `AS3 documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/userguide/composing-a-declaration.html

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_list: Name of Application
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```python
               import pulumi
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: Name of Tenant
        :param pulumi.Input[str] tenant_name: Name of Tenant
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[As3Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        `As3` provides details about bigip as3 resource

        This resource is helpful to configure as3 declarative JSON on BIG-IP.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        # Example Usage for json file
        as3_example1_as3 = f5bigip.As3("as3-example1As3", as3_json=(lambda path: open(path).read())("example1.json"))
        # Example Usage for json file with tenant filter
        as3_example1_index_as3_as3 = f5bigip.As3("as3-example1Index/as3As3",
            as3_json=(lambda path: open(path).read())("example2.json"),
            tenant_filter="Sample_03")
        ```

        ## Import

        As3 resources can be imported using the partition name, e.g., ( use comma separated partition names if there are multiple partitions in as3 deployments )

        ```sh
         $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01
        ```

        ```sh
         $ pulumi import f5bigip:index/as3:As3 bigip_as3.test Sample_http_01,Sample_non_http_01
        ```

        #### Import examples ( single and multiple partitions )

        ```sh
         $ pulumi import f5bigip:index/as3:As3 test Sample_http_01
        ```

         bigip_as3.testImporting from ID "Sample_http_01"... bigip_as3.testImport prepared!

         Prepared bigip_as3 for import bigip_as3.testRefreshing state... [id=Sample_http_01] Import successful! The resources that were imported are shown above. These resources are now in your Terraform state and will henceforth be managed by Terraform. $ terraform show bigip_as3.testresource "bigip_as3" "test" {

         as3_json

        = jsonencode(

         {

         action

        = "deploy"

         class

         = "AS3"

         declaration = {

         Sample_http_01 = {

         A1

        = {

         class

        = "Application"

         jsessionid = {

         class

         = "Persist"

         cookieMethod

        = "hash"

         cookieName

        = "JSESSIONID"

         persistenceMethod = "cookie"

         }

         service

        = {

         class

        = "Service_HTTP"

         persistenceMethods = [

         {

         use = "jsessionid"

         },

         ]

         pool

         = "web_pool"

         virtualAddresses

         = [

         "10.0.2.10",

         ]

         }

         web_pool

         = {

         class

        = "Pool"

         members

        = [

         {

         serverAddresses = [

         "192.0.2.10",

         "192.0.2.11",

         ]

         servicePort

         = 80

         },

         ]

         monitors = [

         "http",

         ]

         }

         }

         class = "Tenant"

         }

         class

        = "ADC"

         id

         = "UDP_DNS_Sample"

         label

        = "UDP_DNS_Sample"

         remark

         = "Sample of a UDP DNS Load Balancer Service"

         schemaVersion

        = "3.0.0"

         }

         persist

         = true

         }

         )

         id

        = "Sample_http_01"

         tenant_filter = "Sample_http_01"

         tenant_list

         = "Sample_http_01" }

        ```sh
         $ pulumi import f5bigip:index/as3:As3 test Sample_http_01,Sample_non_http_01
        ```

         bigip_as3.testImporting from ID "Sample_http_01,Sample_non_http_01"... bigip_as3.testImport prepared!

         Prepared bigip_as3 for import bigip_as3.testRefreshing state... [id=Sample_http_01,Sample_non_http_01] Import successful! The resources that were imported are shown above. These resources are now in your Terraform state and will henceforth be managed by Terraform. $ terraform show bigip_as3.testresource "bigip_as3" "test" {

         as3_json

        = jsonencode(

         {

         action

        = "deploy"

         class

         = "AS3"

         declaration = {

         Sample_http_01

         = {

         A1

        = {

         class

        = "Application"

         jsessionid = {

         class

         = "Persist"

         cookieMethod

        = "hash"

         cookieName

        = "JSESSIONID"

         persistenceMethod = "cookie"

         }

         service

        = {

         class

        = "Service_HTTP"

         persistenceMethods = [

         {

         use = "jsessionid"

         },

         ]

         pool

         = "web_pool"

         virtualAddresses

         = [

         "10.0.2.10",

         ]

         }

         web_pool

         = {

         class

        = "Pool"

         members

        = [

         {

         serverAddresses = [

         "192.0.2.10",

         "192.0.2.11",

         ]

         servicePort

         = 80

         },

         ]

         monitors = [

         "http",

         ]

         }

         }

         class = "Tenant"

         }

         Sample_non_http_01 = {

         DNS_Service = {

         Pool1

         = {

         class

        = "Pool"

         members

        = [

         {

         serverAddresses = [

         "10.1.10.100",

         ]

         servicePort

         = 53

         },

         {

         serverAddresses = [

         "10.1.10.101",

         ]

         servicePort

         = 53

         },

         ]

         monitors = [

         "icmp",

         ]

         }

         class

         = "Application"

         service = {

         class

        = "Service_UDP"

         pool

         = "Pool1"

         virtualAddresses = [

         "10.1.20.121",

         ]

         virtualPort

        = 53

         }

         }

         class

         = "Tenant"

         }

         class

        = "ADC"

         id

         = "UDP_DNS_Sample"

         label

        = "UDP_DNS_Sample"

         remark

         = "Sample of a UDP DNS Load Balancer Service"

         schemaVersion

        = "3.0.0"

         }

         persist

         = true

         }

         )

         id

        = "Sample_http_01,Sample_non_http_01"

         tenant_filter = "Sample_http_01,Sample_non_http_01"

         tenant_list

         = "Sample_http_01,Sample_non_http_01" } * `AS3 documentation` - https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/userguide/composing-a-declaration.html

        :param str resource_name: The name of the resource.
        :param As3Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(As3Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_list: Optional[pulumi.Input[str]] = None,
                 as3_json: Optional[pulumi.Input[str]] = None,
                 ignore_metadata: Optional[pulumi.Input[bool]] = None,
                 task_id: Optional[pulumi.Input[str]] = None,
                 tenant_filter: Optional[pulumi.Input[str]] = None,
                 tenant_list: Optional[pulumi.Input[str]] = None,
                 tenant_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = As3Args.__new__(As3Args)

            __props__.__dict__["application_list"] = application_list
            __props__.__dict__["as3_json"] = as3_json
            __props__.__dict__["ignore_metadata"] = ignore_metadata
            __props__.__dict__["task_id"] = task_id
            __props__.__dict__["tenant_filter"] = tenant_filter
            __props__.__dict__["tenant_list"] = tenant_list
            if tenant_name is not None and not opts.urn:
                warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
                pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")
            __props__.__dict__["tenant_name"] = tenant_name
        super(As3, __self__).__init__(
            'f5bigip:index/as3:As3',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_list: Optional[pulumi.Input[str]] = None,
            as3_json: Optional[pulumi.Input[str]] = None,
            ignore_metadata: Optional[pulumi.Input[bool]] = None,
            task_id: Optional[pulumi.Input[str]] = None,
            tenant_filter: Optional[pulumi.Input[str]] = None,
            tenant_list: Optional[pulumi.Input[str]] = None,
            tenant_name: Optional[pulumi.Input[str]] = None) -> 'As3':
        """
        Get an existing As3 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] application_list: Name of Application
        :param pulumi.Input[str] as3_json: Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        :param pulumi.Input[bool] ignore_metadata: Set True if you want to ignore metadata changes during update. By default it is set to false
               
               * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant
               
               ```python
               import pulumi
               ```
               * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants
               
               ```python
               import pulumi
               ```
        :param pulumi.Input[str] task_id: ID of AS3 post declaration async task
        :param pulumi.Input[str] tenant_filter: If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        :param pulumi.Input[str] tenant_list: Name of Tenant
        :param pulumi.Input[str] tenant_name: Name of Tenant
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _As3State.__new__(_As3State)

        __props__.__dict__["application_list"] = application_list
        __props__.__dict__["as3_json"] = as3_json
        __props__.__dict__["ignore_metadata"] = ignore_metadata
        __props__.__dict__["task_id"] = task_id
        __props__.__dict__["tenant_filter"] = tenant_filter
        __props__.__dict__["tenant_list"] = tenant_list
        __props__.__dict__["tenant_name"] = tenant_name
        return As3(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="applicationList")
    def application_list(self) -> pulumi.Output[str]:
        """
        Name of Application
        """
        return pulumi.get(self, "application_list")

    @property
    @pulumi.getter(name="as3Json")
    def as3_json(self) -> pulumi.Output[Optional[str]]:
        """
        Path/Filename of Declarative AS3 JSON which is a json file used with builtin ```file``` function
        """
        return pulumi.get(self, "as3_json")

    @property
    @pulumi.getter(name="ignoreMetadata")
    def ignore_metadata(self) -> pulumi.Output[Optional[bool]]:
        """
        Set True if you want to ignore metadata changes during update. By default it is set to false

        * `as3_example1.json` - Example  AS3 Declarative JSON file with single tenant

        ```python
        import pulumi
        ```
        * `as3_example2.json` - Example  AS3 Declarative JSON file with multiple tenants

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "ignore_metadata")

    @property
    @pulumi.getter(name="taskId")
    def task_id(self) -> pulumi.Output[str]:
        """
        ID of AS3 post declaration async task
        """
        return pulumi.get(self, "task_id")

    @property
    @pulumi.getter(name="tenantFilter")
    def tenant_filter(self) -> pulumi.Output[Optional[str]]:
        """
        If there are multiple tenants on a BIG-IP, this attribute helps the user to set a particular tenant to which he want to reflect the changes. Other tenants will neither be created nor be modified.
        """
        return pulumi.get(self, "tenant_filter")

    @property
    @pulumi.getter(name="tenantList")
    def tenant_list(self) -> pulumi.Output[str]:
        """
        Name of Tenant
        """
        return pulumi.get(self, "tenant_list")

    @property
    @pulumi.getter(name="tenantName")
    def tenant_name(self) -> pulumi.Output[Optional[str]]:
        """
        Name of Tenant
        """
        warnings.warn("""this attribute is no longer in use""", DeprecationWarning)
        pulumi.log.warn("""tenant_name is deprecated: this attribute is no longer in use""")

        return pulumi.get(self, "tenant_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetWafEntityUrlResult',
    'AwaitableGetWafEntityUrlResult',
    'get_waf_entity_url',
    'get_waf_entity_url_output',
]

@pulumi.output_type
class GetWafEntityUrlResult:
    """
    A collection of values returned by getWafEntityUrl.
    """
    def __init__(__self__, description=None, id=None, json=None, method=None, method_overrides=None, name=None, perform_staging=None, protocol=None, signature_overrides_disables=None, type=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if json and not isinstance(json, str):
            raise TypeError("Expected argument 'json' to be a str")
        pulumi.set(__self__, "json", json)
        if method and not isinstance(method, str):
            raise TypeError("Expected argument 'method' to be a str")
        pulumi.set(__self__, "method", method)
        if method_overrides and not isinstance(method_overrides, list):
            raise TypeError("Expected argument 'method_overrides' to be a list")
        pulumi.set(__self__, "method_overrides", method_overrides)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if perform_staging and not isinstance(perform_staging, bool):
            raise TypeError("Expected argument 'perform_staging' to be a bool")
        pulumi.set(__self__, "perform_staging", perform_staging)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if signature_overrides_disables and not isinstance(signature_overrides_disables, list):
            raise TypeError("Expected argument 'signature_overrides_disables' to be a list")
        pulumi.set(__self__, "signature_overrides_disables", signature_overrides_disables)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def json(self) -> str:
        """
        Json string representing created WAF entity URL declaration in JSON format
        """
        return pulumi.get(self, "json")

    @property
    @pulumi.getter
    def method(self) -> Optional[str]:
        return pulumi.get(self, "method")

    @property
    @pulumi.getter(name="methodOverrides")
    def method_overrides(self) -> Optional[Sequence['outputs.GetWafEntityUrlMethodOverrideResult']]:
        return pulumi.get(self, "method_overrides")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="performStaging")
    def perform_staging(self) -> Optional[bool]:
        return pulumi.get(self, "perform_staging")

    @property
    @pulumi.getter
    def protocol(self) -> Optional[str]:
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="signatureOverridesDisables")
    def signature_overrides_disables(self) -> Optional[Sequence[int]]:
        return pulumi.get(self, "signature_overrides_disables")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


class AwaitableGetWafEntityUrlResult(GetWafEntityUrlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWafEntityUrlResult(
            description=self.description,
            id=self.id,
            json=self.json,
            method=self.method,
            method_overrides=self.method_overrides,
            name=self.name,
            perform_staging=self.perform_staging,
            protocol=self.protocol,
            signature_overrides_disables=self.signature_overrides_disables,
            type=self.type)


def get_waf_entity_url(description: Optional[str] = None,
                       method: Optional[str] = None,
                       method_overrides: Optional[Sequence[pulumi.InputType['GetWafEntityUrlMethodOverrideArgs']]] = None,
                       name: Optional[str] = None,
                       perform_staging: Optional[bool] = None,
                       protocol: Optional[str] = None,
                       signature_overrides_disables: Optional[Sequence[int]] = None,
                       type: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWafEntityUrlResult:
    """
    Use this data source (`ssl_get_waf_pb_suggestions`) to create JSON for WAF URL to later use with an existing WAF policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    w_afurl1 = f5bigip.ssl.get_waf_entity_url(description="this is a test",
        method_overrides=[
            f5bigip.ssl.GetWafEntityUrlMethodOverrideArgs(
                allow=False,
                method="BCOPY",
            ),
            f5bigip.ssl.GetWafEntityUrlMethodOverrideArgs(
                allow=True,
                method="BDELETE",
            ),
        ],
        name="/foobar",
        perform_staging=True,
        protocol="HTTP",
        signature_overrides_disables=[
            12345678,
            87654321,
        ],
        type="explicit")
    ```


    :param str description: A description of the URL.
    :param str method: Specifies an HTTP method.
    :param Sequence[pulumi.InputType['GetWafEntityUrlMethodOverrideArgs']] method_overrides: A list of methods that are allowed or disallowed for a specific URL.
    :param str name: WAF entity URL name.
    :param bool perform_staging: If true then any violation associated to the respective URL will not be enforced, and the request will not be considered illegal.
    :param str protocol: Specifies whether the protocol for the URL is 'http' or 'https'. Default is: http.
    :param Sequence[int] signature_overrides_disables: List of Attack Signature Ids which are disabled for this particular URL.
    :param str type: Specifies whether the parameter is an 'explicit' or a 'wildcard' attribute. Default is: wildcard.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['method'] = method
    __args__['methodOverrides'] = method_overrides
    __args__['name'] = name
    __args__['performStaging'] = perform_staging
    __args__['protocol'] = protocol
    __args__['signatureOverridesDisables'] = signature_overrides_disables
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ssl/getWafEntityUrl:getWafEntityUrl', __args__, opts=opts, typ=GetWafEntityUrlResult).value

    return AwaitableGetWafEntityUrlResult(
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        json=pulumi.get(__ret__, 'json'),
        method=pulumi.get(__ret__, 'method'),
        method_overrides=pulumi.get(__ret__, 'method_overrides'),
        name=pulumi.get(__ret__, 'name'),
        perform_staging=pulumi.get(__ret__, 'perform_staging'),
        protocol=pulumi.get(__ret__, 'protocol'),
        signature_overrides_disables=pulumi.get(__ret__, 'signature_overrides_disables'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_waf_entity_url)
def get_waf_entity_url_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                              method: Optional[pulumi.Input[Optional[str]]] = None,
                              method_overrides: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetWafEntityUrlMethodOverrideArgs']]]]] = None,
                              name: Optional[pulumi.Input[str]] = None,
                              perform_staging: Optional[pulumi.Input[Optional[bool]]] = None,
                              protocol: Optional[pulumi.Input[Optional[str]]] = None,
                              signature_overrides_disables: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                              type: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetWafEntityUrlResult]:
    """
    Use this data source (`ssl_get_waf_pb_suggestions`) to create JSON for WAF URL to later use with an existing WAF policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    w_afurl1 = f5bigip.ssl.get_waf_entity_url(description="this is a test",
        method_overrides=[
            f5bigip.ssl.GetWafEntityUrlMethodOverrideArgs(
                allow=False,
                method="BCOPY",
            ),
            f5bigip.ssl.GetWafEntityUrlMethodOverrideArgs(
                allow=True,
                method="BDELETE",
            ),
        ],
        name="/foobar",
        perform_staging=True,
        protocol="HTTP",
        signature_overrides_disables=[
            12345678,
            87654321,
        ],
        type="explicit")
    ```


    :param str description: A description of the URL.
    :param str method: Specifies an HTTP method.
    :param Sequence[pulumi.InputType['GetWafEntityUrlMethodOverrideArgs']] method_overrides: A list of methods that are allowed or disallowed for a specific URL.
    :param str name: WAF entity URL name.
    :param bool perform_staging: If true then any violation associated to the respective URL will not be enforced, and the request will not be considered illegal.
    :param str protocol: Specifies whether the protocol for the URL is 'http' or 'https'. Default is: http.
    :param Sequence[int] signature_overrides_disables: List of Attack Signature Ids which are disabled for this particular URL.
    :param str type: Specifies whether the parameter is an 'explicit' or a 'wildcard' attribute. Default is: wildcard.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetAzureServiceDiscoveryResult',
    'AwaitableGetAzureServiceDiscoveryResult',
    'get_azure_service_discovery',
    'get_azure_service_discovery_output',
]

@pulumi.output_type
class GetAzureServiceDiscoveryResult:
    """
    A collection of values returned by getAzureServiceDiscovery.
    """
    def __init__(__self__, address_realm=None, azure_sd_json=None, credential_update=None, id=None, minimum_monitors=None, port=None, resource_group=None, subscription_id=None, tag_key=None, tag_value=None, type=None, undetectable_action=None, update_interval=None):
        if address_realm and not isinstance(address_realm, str):
            raise TypeError("Expected argument 'address_realm' to be a str")
        pulumi.set(__self__, "address_realm", address_realm)
        if azure_sd_json and not isinstance(azure_sd_json, str):
            raise TypeError("Expected argument 'azure_sd_json' to be a str")
        pulumi.set(__self__, "azure_sd_json", azure_sd_json)
        if credential_update and not isinstance(credential_update, bool):
            raise TypeError("Expected argument 'credential_update' to be a bool")
        pulumi.set(__self__, "credential_update", credential_update)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if minimum_monitors and not isinstance(minimum_monitors, str):
            raise TypeError("Expected argument 'minimum_monitors' to be a str")
        pulumi.set(__self__, "minimum_monitors", minimum_monitors)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if resource_group and not isinstance(resource_group, str):
            raise TypeError("Expected argument 'resource_group' to be a str")
        pulumi.set(__self__, "resource_group", resource_group)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)
        if tag_key and not isinstance(tag_key, str):
            raise TypeError("Expected argument 'tag_key' to be a str")
        pulumi.set(__self__, "tag_key", tag_key)
        if tag_value and not isinstance(tag_value, str):
            raise TypeError("Expected argument 'tag_value' to be a str")
        pulumi.set(__self__, "tag_value", tag_value)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if undetectable_action and not isinstance(undetectable_action, str):
            raise TypeError("Expected argument 'undetectable_action' to be a str")
        pulumi.set(__self__, "undetectable_action", undetectable_action)
        if update_interval and not isinstance(update_interval, str):
            raise TypeError("Expected argument 'update_interval' to be a str")
        pulumi.set(__self__, "update_interval", update_interval)

    @property
    @pulumi.getter(name="addressRealm")
    def address_realm(self) -> Optional[str]:
        return pulumi.get(self, "address_realm")

    @property
    @pulumi.getter(name="azureSdJson")
    def azure_sd_json(self) -> str:
        """
        The JSON for Azure service discovery block.
        """
        return pulumi.get(self, "azure_sd_json")

    @property
    @pulumi.getter(name="credentialUpdate")
    def credential_update(self) -> Optional[bool]:
        return pulumi.get(self, "credential_update")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="minimumMonitors")
    def minimum_monitors(self) -> Optional[str]:
        return pulumi.get(self, "minimum_monitors")

    @property
    @pulumi.getter
    def port(self) -> Optional[int]:
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="resourceGroup")
    def resource_group(self) -> str:
        return pulumi.get(self, "resource_group")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> str:
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter(name="tagKey")
    def tag_key(self) -> Optional[str]:
        return pulumi.get(self, "tag_key")

    @property
    @pulumi.getter(name="tagValue")
    def tag_value(self) -> Optional[str]:
        return pulumi.get(self, "tag_value")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="undetectableAction")
    def undetectable_action(self) -> Optional[str]:
        return pulumi.get(self, "undetectable_action")

    @property
    @pulumi.getter(name="updateInterval")
    def update_interval(self) -> Optional[str]:
        return pulumi.get(self, "update_interval")


class AwaitableGetAzureServiceDiscoveryResult(GetAzureServiceDiscoveryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAzureServiceDiscoveryResult(
            address_realm=self.address_realm,
            azure_sd_json=self.azure_sd_json,
            credential_update=self.credential_update,
            id=self.id,
            minimum_monitors=self.minimum_monitors,
            port=self.port,
            resource_group=self.resource_group,
            subscription_id=self.subscription_id,
            tag_key=self.tag_key,
            tag_value=self.tag_value,
            type=self.type,
            undetectable_action=self.undetectable_action,
            update_interval=self.update_interval)


def get_azure_service_discovery(address_realm: Optional[str] = None,
                                credential_update: Optional[bool] = None,
                                minimum_monitors: Optional[str] = None,
                                port: Optional[int] = None,
                                resource_group: Optional[str] = None,
                                subscription_id: Optional[str] = None,
                                tag_key: Optional[str] = None,
                                tag_value: Optional[str] = None,
                                type: Optional[str] = None,
                                undetectable_action: Optional[str] = None,
                                update_interval: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAzureServiceDiscoveryResult:
    """
    Use this data source (`fast_get_azure_service_discovery`) to get the Azure Service discovery config to be used for `http`/`https` app deployment in FAST.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    t_c3 = f5bigip.fast.get_azure_service_discovery(resource_group="testazurerg",
        subscription_id="testazuresid",
        tag_key="testazuretag",
        tag_value="testazurevalue")
    ```


    :param str address_realm: Specifies whether to look for public or private IP addresses,default `private`.
    :param bool credential_update: Specifies whether you are updating your credentials,default `false`.
    :param str minimum_monitors: Member is down when fewer than minimum monitors report it healthy.
    :param int port: Port to be used for Azure service discovery,default `80`.
    :param str resource_group: Azure Resource Group name.
    :param str subscription_id: Azure subscription ID.
    :param str tag_key: The tag key associated with the node to add to this pool.
    :param str tag_value: The tag value associated with the node to add to this pool.
    :param str undetectable_action: Action to take when node cannot be detected,default `remove`.
    :param str update_interval: Update interval for service discovery.
    """
    __args__ = dict()
    __args__['addressRealm'] = address_realm
    __args__['credentialUpdate'] = credential_update
    __args__['minimumMonitors'] = minimum_monitors
    __args__['port'] = port
    __args__['resourceGroup'] = resource_group
    __args__['subscriptionId'] = subscription_id
    __args__['tagKey'] = tag_key
    __args__['tagValue'] = tag_value
    __args__['type'] = type
    __args__['undetectableAction'] = undetectable_action
    __args__['updateInterval'] = update_interval
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:fast/getAzureServiceDiscovery:getAzureServiceDiscovery', __args__, opts=opts, typ=GetAzureServiceDiscoveryResult).value

    return AwaitableGetAzureServiceDiscoveryResult(
        address_realm=pulumi.get(__ret__, 'address_realm'),
        azure_sd_json=pulumi.get(__ret__, 'azure_sd_json'),
        credential_update=pulumi.get(__ret__, 'credential_update'),
        id=pulumi.get(__ret__, 'id'),
        minimum_monitors=pulumi.get(__ret__, 'minimum_monitors'),
        port=pulumi.get(__ret__, 'port'),
        resource_group=pulumi.get(__ret__, 'resource_group'),
        subscription_id=pulumi.get(__ret__, 'subscription_id'),
        tag_key=pulumi.get(__ret__, 'tag_key'),
        tag_value=pulumi.get(__ret__, 'tag_value'),
        type=pulumi.get(__ret__, 'type'),
        undetectable_action=pulumi.get(__ret__, 'undetectable_action'),
        update_interval=pulumi.get(__ret__, 'update_interval'))


@_utilities.lift_output_func(get_azure_service_discovery)
def get_azure_service_discovery_output(address_realm: Optional[pulumi.Input[Optional[str]]] = None,
                                       credential_update: Optional[pulumi.Input[Optional[bool]]] = None,
                                       minimum_monitors: Optional[pulumi.Input[Optional[str]]] = None,
                                       port: Optional[pulumi.Input[Optional[int]]] = None,
                                       resource_group: Optional[pulumi.Input[str]] = None,
                                       subscription_id: Optional[pulumi.Input[str]] = None,
                                       tag_key: Optional[pulumi.Input[Optional[str]]] = None,
                                       tag_value: Optional[pulumi.Input[Optional[str]]] = None,
                                       type: Optional[pulumi.Input[Optional[str]]] = None,
                                       undetectable_action: Optional[pulumi.Input[Optional[str]]] = None,
                                       update_interval: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAzureServiceDiscoveryResult]:
    """
    Use this data source (`fast_get_azure_service_discovery`) to get the Azure Service discovery config to be used for `http`/`https` app deployment in FAST.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    t_c3 = f5bigip.fast.get_azure_service_discovery(resource_group="testazurerg",
        subscription_id="testazuresid",
        tag_key="testazuretag",
        tag_value="testazurevalue")
    ```


    :param str address_realm: Specifies whether to look for public or private IP addresses,default `private`.
    :param bool credential_update: Specifies whether you are updating your credentials,default `false`.
    :param str minimum_monitors: Member is down when fewer than minimum monitors report it healthy.
    :param int port: Port to be used for Azure service discovery,default `80`.
    :param str resource_group: Azure Resource Group name.
    :param str subscription_id: Azure subscription ID.
    :param str tag_key: The tag key associated with the node to add to this pool.
    :param str tag_value: The tag value associated with the node to add to this pool.
    :param str undetectable_action: Action to take when node cannot be detected,default `remove`.
    :param str update_interval: Update interval for service discovery.
    """
    ...
